##################
ODIN documentation
##################

**Object Data Mapper for Python**

First Steps
***********

Quick overview to get up to speed with Odin.

* :doc:`intro/creating-resources`
* :doc:`intro/loading-and-saving-data`
* :doc:`intro/mapping-between-resources`

Working with resources
**********************

Resources are the basic building block of Odin.

* Resources: :doc:`ref/resources/fields` | :doc:`ref/resources/options`
* Loading and Saving: :doc:`ref/codecs/json_codec` | :doc:`ref/codecs/yaml_codec` | :doc:`ref/codecs/csv_codec` | :doc:`ref/codecs/msgpack_codec`
* Mapping: :doc:`ref/mapping/classes`
* Adapters: :doc:`ref/adapters`
* Documenting: :doc:`ref/contrib/sphinx/index`

See the :doc:`examples/index` section for examples on how to use features of Odin.

Extras
******

* :doc:`ref/contrib/money/index`
* :doc:`ref/contrib/geo/index`
* :doc:`ref/contrib/pint/index`

Integration
***********

* :doc:`integration/aws/index`
* :doc:`integration/django/index`

Project Links
*************

* `Project home <https://github.com/python-odin/odin>`_
* `Issue/Bug tracker <https://github.com/python-odin/odin/issues>`_

Indices and tables
******************

* :doc:`contents`
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
